@@ -62,6 +62,9 @@ def remove(target, arg):
 def cleanup(target, arg):
     target.Package.cleanup()
 
+def flatpak(target, arg):
+    target.flatpak.install(arg)
+
 def status(target, arg):
     target.Service.status(arg)
 
